From 644ed3e30bbee9a417dfbe649f2a72df25a7efb1 Mon Sep 17 00:00:00 2001
From: Administrator <admin>
Date: Wed, 18 May 2022 10:10:33 +0800
Subject: [PATCH] Merge remote-tracking branch 'origin/master'

---
 src/main/java/org/springblade/modules/FTP/FtpUtil.java |  118 +++++++++++++++++++++++++++++++++++++++++++---------------
 1 files changed, 87 insertions(+), 31 deletions(-)

diff --git a/src/main/java/org/springblade/modules/FTP/FtpUtil.java b/src/main/java/org/springblade/modules/FTP/FtpUtil.java
index 0c9dca7..b539771 100644
--- a/src/main/java/org/springblade/modules/FTP/FtpUtil.java
+++ b/src/main/java/org/springblade/modules/FTP/FtpUtil.java
@@ -11,6 +11,8 @@
 import java.io.*;
 import java.net.SocketException;
 import java.util.Date;
+import java.util.Map;
+
 import net.lingala.zip4j.core.ZipFile;
 
 import static org.springblade.common.config.FtpConfig.*;
@@ -36,17 +38,17 @@
 	 * 获取FTPClient对象
 	 *
 	 * @param ftpHost     FTP主机服务器
 	 * @param ftpPassword FTP 登录密码
 	 * @param ftpUserName FTP登录用户名
 	 * @param ftpPort     FTP端口 默认为21
 	 * @return
 	 */
-	public static FTPClient getFTPClient(String ftpHost, int ftpPort, String ftpUserName, String ftpPassword) {
+	public static FTPClient getFTPClient(String ftpHost, int ftpPort, String ftpUserNameOut, String ftpPasswordOut) {
 		FTPClient ftpClient = null;
 		try {
 			ftpClient = new FTPClient();
 			ftpClient.connect(ftpHost, ftpPort);// 连接FTP服务器
-			ftpClient.login(ftpUserName, ftpPassword);// 登陆FTP服务器
+			ftpClient.login(ftpUserNameOut, ftpPasswordOut);// 登陆FTP服务器
 			if (!FTPReply.isPositiveCompletion(ftpClient.getReplyCode())) {
 				logger.info("未连接到FTP,用户名或密码错误。");
 				ftpClient.disconnect();
@@ -67,20 +69,20 @@
 	 * 从FTP服务器下载文件
 	 *
 	 * @param ftpHost     FTP IP地址
 	 * @param ftpUserName FTP 用户名
 	 * @param ftpPassword FTP用户名密码
 	 * @param ftpPort     FTP端口
 	 * @param ftpPath     FTP服务器中文件所在路径 格式: ftptest/aa
 	 * @param localPath   下载到本地的位置 格式:H:/download
 	 * @param fileName    文件名称
 	 */
-	public static void downloadFtpFile(String ftpHost, String ftpUserName, String ftpPassword, int ftpPort,
+	public static void downloadFtpFile(String ftpHost, String ftpUserNameOut, String ftpPasswordOut, int ftpPort,
 									   String ftpPath, String localPath, String fileName) {
 
 		FTPClient ftpClient = null;
 
 		try {
-			ftpClient = getFTPClient(ftpHost, ftpPort, ftpUserName, ftpPassword);
+			ftpClient = getFTPClient(ftpHost, ftpPort, ftpUserNameOut, ftpPasswordOut);
 			// 设置上传文件的类型为二进制类型
 			if (FTPReply.isPositiveCompletion(ftpClient.sendCommand("OPTS UTF8", "ON"))) {// 开启服务器对UTF-8的支持,如果服务器支持就用UTF-8编码,否则就使用本地编码(GBK).
 				LOCAL_CHARSET = "UTF-8";
@@ -133,13 +135,13 @@
 	}
 
 
-	public static boolean uploadFile(String ftpHost, int ftpPort, String ftpUserName, String ftpPassword,
+	public static boolean uploadFile(String ftpHost, int ftpPort, String ftpUserNameOut, String ftpPasswordOut,
 									 String basePath, String filePath, String filename, InputStream input) {
 		boolean result = false;
 		FTPClient ftpClient = null;
 		try {
 			int reply;
-			ftpClient = getFTPClient(ftpHost, ftpPort, ftpUserName, ftpPassword);
+			ftpClient = getFTPClient(ftpHost, ftpPort, ftpUserNameOut, ftpPasswordOut);
 			reply = ftpClient.getReplyCode();
 			if (!FTPReply.isPositiveCompletion(reply)) {
 				ftpClient.disconnect();
@@ -198,12 +200,12 @@
 	}
 
 
-	public static boolean deleteFile(String ftpHost, int ftpPort, String ftpUserName, String ftpPassword, String pathname,
+	public static boolean deleteFile(String ftpHost, int ftpPort, String ftpUserNameOut, String ftpPasswordOut, String pathname,
 									 String filename) {
 		boolean flag = false;
 		FTPClient ftpClient = new FTPClient();
 		try {
-			ftpClient = getFTPClient(ftpHost, ftpPort, ftpUserName, ftpPassword);
+			ftpClient = getFTPClient(ftpHost, ftpPort, ftpUserNameOut, ftpPasswordOut);
 			// 验证FTP服务器是否登录成功
 			int replyCode = ftpClient.getReplyCode();
 			if (!FTPReply.isPositiveCompletion(replyCode)) {
@@ -288,23 +290,7 @@
 			}
 		}
 	}
-	/**
-	 * 执行sql 上传
-	 * @param s1 sql
-	 */
-	public static void sqlFileUpload(String s1){
-		String json1 = JSON.toJSONString(s1);
-		String response1 = String.valueOf((new Date()).getTime());
-		OutJson.createJsonFile(json1, localPath, "nsql"+response1);
-		FileInputStream in1 = null;
-		try {
-			in1 = new FileInputStream(new File(localPath + "nsql"+response1+".json"));
-		} catch (FileNotFoundException e) {
-			e.printStackTrace();
-		}
-		FtpUtil.uploadFile(ftpHost, ftpPort, ftpUserName, ftpPassword, ftpPath, "/",  "nsql"+response1+".json", in1);
-//		MysqlCenlint.deletess("nsql"+response1+".json");
-	}
+
 	/**
 	 *
 	 * 解压zip 包
@@ -357,6 +343,23 @@
 		}
 	}
 
+	/**
+	 * 执行sql 上传
+	 * @param obj sql
+	 */
+	public static void sqlFileUpload(String obj){
+		String json1 = JSON.toJSONString(obj);
+		String response1 = String.valueOf((new Date()).getTime());
+		OutJson.createJsonFile(json1, localPath, "nsql"+response1);
+		FileInputStream in1 = null;
+		try {
+			in1 = new FileInputStream(new File(localPath + "nsql"+response1+".json"));
+		} catch (FileNotFoundException e) {
+			e.printStackTrace();
+		}
+		FtpUtil.uploadFile(ftpHost, ftpPort, ftpUserNameOut, ftpPasswordOut, ftpPath, "/",  "nsql"+response1+".json", in1);
+		MysqlCenlint.deletess("nsql"+response1+".json");
+	}
 
 	/**
 	 * 执行 对象数据(用户,报名对象信息等) 上传
@@ -372,10 +375,63 @@
 		} catch (FileNotFoundException e) {
 			e.printStackTrace();
 		}
-		FtpUtil.uploadFile(ftpHost, ftpPort, ftpUserName, ftpPassword, ftpPath, "/",  "n"+response1+".json", in1);
-//		MysqlCenlint.deletess("n"+response1+".json");
+		FtpUtil.uploadFile(ftpHost, ftpPort, ftpUserNameOut, ftpPasswordOut, ftpPath, "/",  "n"+response1+".json", in1);
+		System.out.println("用户新增,向外网推送数据结束.................");
+		MysqlCenlint.deletess("n"+response1+".json");
 	}
 
 
+	/**
+	 * 执行 对象数据(用户,报名对象信息等) 上传
+	 * @param obj 对象信息
+	 */
+	public static void objectFileUploadList(Object obj){
+		String json1 = JSON.toJSONString(obj);
+		String response1 = String.valueOf((new Date()).getTime());
+		OutJson.createJsonFile(json1, localPath, "nl"+response1);
+		FileInputStream in1 = null;
+		try {
+			in1 = new FileInputStream(new File(localPath + "nl"+response1+".json"));
+		} catch (FileNotFoundException e) {
+			e.printStackTrace();
+		}
+		FtpUtil.uploadFile(ftpHost, ftpPort, ftpUserNameOut, ftpPasswordOut, ftpPath, "/",  "nl"+response1+".json", in1);
+		MysqlCenlint.deletess("nl"+response1+".json");
+	}
 
+	/**
+	 * 返回报名信息结果
+	 * @param obj
+	 */
+	public static void objectFileUploadListTrain(Object obj){
+		String json1 = JSON.toJSONString(obj);
+		String response1 = String.valueOf((new Date()).getTime());
+		OutJson.createJsonFile(json1, localPath, "nt"+response1);
+		FileInputStream in1 = null;
+		try {
+			in1 = new FileInputStream(new File(localPath + "nt"+response1+".json"));
+		} catch (FileNotFoundException e) {
+			e.printStackTrace();
+		}
+		FtpUtil.uploadFile(ftpHost, ftpPort, ftpUserNameOut, ftpPasswordOut, ftpPath, "/",  "nt"+response1+".json", in1);
+		MysqlCenlint.deletess("nt"+response1+".json");
+	}
+
+	/**
+	 * 向外网发送保安员证编号位数数据
+	 * @param map1
+	 */
+	public static void objectFileUploadSecurityNumberCount(Object obj){
+		String json1 = JSON.toJSONString(obj);
+		String response1 = String.valueOf((new Date()).getTime());
+		OutJson.createJsonFile(json1, localPath, "ns"+response1);
+		FileInputStream in1 = null;
+		try {
+			in1 = new FileInputStream(new File(localPath + "ns"+response1+".json"));
+		} catch (FileNotFoundException e) {
+			e.printStackTrace();
+		}
+		FtpUtil.uploadFile(ftpHost, ftpPort, ftpUserNameOut, ftpPasswordOut, ftpPath, "/",  "ns"+response1+".json", in1);
+		MysqlCenlint.deletess("ns"+response1+".json");
+	}
 }
@@ -36,17 +38,17 @@
 	 *
 	 * @param ftpHost     FTP主机服务器
-	 * @param ftpPassword FTP 登录密码
-	 * @param ftpUserName FTP登录用户名
+	 * @param ftpPasswordOut FTP 登录密码
+	 * @param ftpUserNameOut FTP登录用户名
 	 * @param ftpPort     FTP端口 默认为21
 	 * @return
@@ -67,20 +69,20 @@
 	 *
 	 * @param ftpHost     FTP IP地址
-	 * @param ftpUserName FTP 用户名
-	 * @param ftpPassword FTP用户名密码
+	 * @param ftpUserNameOut FTP 用户名
+	 * @param ftpPasswordOut FTP用户名密码
 	 * @param ftpPort     FTP端口
 	 * @param ftpPath     FTP服务器中文件所在路径 格式: ftptest/aa

--
Gitblit v1.9.3